@@ -3,7 +3,7 @@ package Alien::Base::PkgConfig;
 use strict;
 use warnings;
 
-our $VERSION = '0.027_03';
+our $VERSION = '0.028_01';
 $VERSION = eval $VERSION;
 
 use Carp;
@@ -51,9 +51,9 @@ sub read {
     or croak "Cannot open .pc file $path: $!";
 
   while (<$fh>) {
-    if (/(.*?)=([^\n\r]*)/) {
+    if (/^([^=:]+?)=([^\n\r]*)/) {
       $self->{vars}{$1} = $2;
-    } elsif (/^(.*?):\s*([^\n\r]*)/) {
+    } elsif (/^([^=:]+?):\s*([^\n\r]*)/) {
       $self->{keywords}{$1} = $2;
     }
   }
